<?xml version="1.0" encoding="utf-8"?>

<!--

This plugin gets close to exporting based on the specification at:
http://www.creativyst.com/Doc/Articles/CSV/CSV01.htm

-->


<xsl:stylesheet version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:oo="http://www.omnigroup.com/namespace/OmniOutliner/v3"
    exclude-result-prefixes="oo"
>

    <xsl:include href="common.xsl" />

    <xsl:output method="text"
              encoding="utf-16"
              indent="no"/>

    <xsl:variable name="non-note-columns" select="oo:outline/oo:columns/oo:column[not(@is-note-column) or @is-note-column != 'yes']" />
    <xsl:strip-space elements="*" />

    <xsl:variable name="note-column-position">
        <xsl:for-each select="oo:outline/oo:columns">
          <xsl:if test="@is-note-column = 'yes'">
            <xsl:value-of select="position()"/>
          </xsl:if>
        </xsl:for-each>
    </xsl:variable>

    <xsl:variable name="outline-column-position">
        <xsl:for-each select="$non-note-columns">
          <xsl:if test="@is-outline-column = 'yes'">
            <xsl:value-of select="position()"/>
          </xsl:if>
        </xsl:for-each>
    </xsl:variable>

    <xsl:variable name="delimiter">,</xsl:variable>

    <xsl:template match="/">
        <xsl:apply-templates select="oo:outline/oo:columns"/>
        <xsl:apply-templates select="oo:outline/oo:root/oo:item" />
    </xsl:template>

    <!-- get our column headers in there -->
    <xsl:template match="oo:columns">
        <!-- only show the column titles if they're visible in the outline -->
        <xsl:if test="not(/oo:outline/oo:editor[@column-titles-display-mode]) or 
                        (/oo:outline/oo:editor[@column-titles-display-mode = 'auto'] and count(/oo:outline/oo:columns/oo:column) > 2 )">
            <xsl:for-each select="$non-note-columns/oo:title">
                <xsl:call-template name="emit-value" />
                
                <!-- don't emit a comma after the last column -->
                <xsl:if test="count($non-note-columns) != position()">
                    <xsl:value-of select="$delimiter" />
                </xsl:if>
                
            </xsl:for-each>
            <xsl:text>&#xa;</xsl:text>
        </xsl:if>
    </xsl:template> 

    <xsl:template match="oo:item">
    
        <xsl:for-each select="oo:values/*">

            <xsl:call-template name="emit-value" />
            
            <!-- don't emit a comma after the last column -->
            <xsl:if test="count($non-note-columns) != position()">
                <xsl:value-of select="$delimiter" />
            </xsl:if>
        </xsl:for-each>
        
        <xsl:text>&#xa;</xsl:text>

        <xsl:apply-templates select="oo:children"/>

    </xsl:template>
    
    <xsl:template name="emit-value" >
    
        <!-- are there any embedded commas? -->
        <xsl:variable name="contains-commas" select="contains(child::*, ',')" />
        
        <!-- are there any embedded quotes? -->
        <xsl:variable name="quote-char">&quot;</xsl:variable>
        <xsl:variable name="double-quote-char">&quot;&quot;</xsl:variable>
        <xsl:variable name="contains-quotes" select="contains(child::*, $quote-char)" />
        
        <!-- wrap everything in double quotes since there are so many situations where
             you would need to do it anyway -->
             
        <xsl:text>"</xsl:text>
        
        <!-- if there are embedded quotes they need to be replaced with double-quotes -->
        <xsl:choose>
            <xsl:when test="$contains-quotes">
                <xsl:call-template name="substitute">
                    <xsl:with-param name="string" select="child::*" />
                    <xsl:with-param name="from" select="$quote-char" />
                    <xsl:with-param name="to" select="$double-quote-char" />
                </xsl:call-template>
            </xsl:when>
            
            <xsl:otherwise>
                <xsl:apply-templates />
            </xsl:otherwise>
        </xsl:choose>
        
        <xsl:text>"</xsl:text>
    
    </xsl:template>

    <xsl:template match="oo:p">
        <xsl:if test="preceding-sibling::oo:p">
            <xsl:text>&#xa;</xsl:text>
        </xsl:if>
        <xsl:apply-templates />
        
    </xsl:template>

    <xsl:template match="oo:children">
        <xsl:apply-templates />
    </xsl:template>

    <xsl:template match="oo:cell" />
    <xsl:template match="oo:style" />

</xsl:stylesheet>