<?xml version="1.0"?>
<xsl:stylesheet
    version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:oo="http://www.omnigroup.com/namespace/OmniOutliner/v3"
    exclude-result-prefixes="oo">
   
<xsl:output method="xml" indent="yes"/>

<!-- Common LaTeX routines -->

	<xsl:template match="/">
	    <xsl:text>\documentclass{</xsl:text>
	    <xsl:value-of select="$documentClass" />
		<xsl:text>}&#xa;</xsl:text>
	    <xsl:text>\title{</xsl:text>
	    <xsl:value-of select="/oo:outline/oo:outline-title/oo:text/oo:p/oo:run/oo:lit"/>
	    <xsl:text>}&#xa;</xsl:text>

	    <xsl:apply-templates select="oo:outline/oo:root/oo:item" />
	</xsl:template>

	<xsl:template match="oo:item">

	    <!-- Page breaks -->
	    <xsl:if test="oo:style/oo:value[@key = 'item-page-break(com.omnigroup.OmniOutliner)']">
	        <xsl:text>\newpage&#xa;</xsl:text>
	    </xsl:if>

	    <xsl:variable name="current-level">
	      <xsl:value-of select="count(ancestor-or-self::oo:item)"/>
	    </xsl:variable>
    
	    <xsl:variable name="text">
	        <xsl:value-of select="oo:values/oo:text/oo:p/oo:run/oo:lit/text()" />
	    </xsl:variable>
    
	    <xsl:variable name="category">
	        <xsl:choose>
	            <xsl:when test="$current-level = 1">
			        <xsl:value-of select="$level1" />
	            </xsl:when>
	            <xsl:when test="$current-level = 2">
			        <xsl:value-of select="$level2" />
	            </xsl:when>
	            <xsl:when test="$current-level > 2">
			        <xsl:value-of select="$level3" />
	            </xsl:when>
        
	        </xsl:choose>
	    </xsl:variable>

	    <xsl:choose>
	        <xsl:when test="starts-with($text, '%') or starts-with($text, '\')">
	            <xsl:value-of select="$text" />
	        </xsl:when>
			<xsl:when test="$current-level > 3 or $text = '' or count(oo:children) = 0">
				<xsl:value-of select="$text" />
		        <xsl:text>&#xa;</xsl:text>
			</xsl:when>
	        <xsl:otherwise>

	            <xsl:text>\</xsl:text>
	            <xsl:value-of select="$category" />
	            <xsl:text>{</xsl:text><xsl:value-of select="$text" /><xsl:text>}</xsl:text>
	        </xsl:otherwise>
	    </xsl:choose>
	    <xsl:text>&#xa;</xsl:text>
    
	    <xsl:apply-templates select="oo:note"/>
	    <xsl:apply-templates select="oo:values/descendant::*/oo:cell"/>
	    <xsl:apply-templates select="oo:children"/>

	</xsl:template>

    <xsl:template match="oo:note/oo:text/oo:p">
        <xsl:apply-templates />
        <xsl:text>&#xa;</xsl:text>
    </xsl:template>

    <xsl:template match="oo:note/oo:text/oo:p/oo:run/oo:style">
    </xsl:template>

    <xsl:template match="oo:note/oo:text/oo:p/oo:run">
 
        <xsl:variable name="style-name" select="oo:style/oo:inherited-style[1]/@name" />

        <xsl:choose>
            <!-- Figure out if we're using a named style or not -->
            <xsl:when test="$style-name != ''">
            
                <!-- Determine if it's a specially formatted style name -->
                <xsl:choose>
                
                    <!-- The style name starts with \ so it should be emitted like \name{foo} -->
                    <xsl:when test="starts-with($style-name, '\')">
                        <xsl:value-of select="$style-name" />
                        <xsl:text>{</xsl:text>
                        <xsl:apply-templates />
                        <xsl:text>}&#xa;</xsl:text>
                    </xsl:when>

                    <!-- The style name starts with ^ so it needs to go out like \begin{foo}bar\end{foo} -->
                    <xsl:when test="starts-with($style-name, '^')">
                        
                        <!-- Strip the ^ off the front -->
                        <xsl:variable name="stripped-name" select="translate($style-name, '^', '')" />
                        <xsl:text>\begin{</xsl:text>
                        <xsl:value-of select="$stripped-name" />
                        <xsl:text>}&#xa;</xsl:text>
                        
                        <xsl:apply-templates />
                        <xsl:text>&#xa;\end{</xsl:text>
                        <xsl:value-of select="$stripped-name" />
                        <xsl:text>}&#xa;</xsl:text>

                    </xsl:when>
                    
                    <xsl:otherwise>
                        <xsl:apply-templates />
                    </xsl:otherwise>
                </xsl:choose>
            
            </xsl:when>
            
            <xsl:otherwise>
                <xsl:apply-templates />
            </xsl:otherwise>
        </xsl:choose>

    </xsl:template>
    
    <xsl:template match="oo:cell">

        <xsl:variable name="refid" select="@refid"/>
        
        <xsl:variable name="filename">
            <xsl:value-of select="/oo:outline/oo:attachments/oo:attachment[@id = $refid]/@href"/>
        </xsl:variable>
	    <xsl:text>&#xa;</xsl:text>

        <xsl:choose>
            <xsl:when test="@type = 'image' or @type = 'com.adobe.pdf'">
                <xsl:call-template name="cell-image" >
                    <xsl:with-param name="filename" select="$filename"/>
                </xsl:call-template>
            </xsl:when>
            <xsl:otherwise>
                <xsl:call-template name="cell-link" >
                    <xsl:with-param name="filename" select="$filename"/>
                </xsl:call-template>
            </xsl:otherwise>    
        </xsl:choose>

    </xsl:template>

    <xsl:template name="cell-image">
        <xsl:param name="filename"/>
        <xsl:text>\begin{figure}&#xa;</xsl:text>
        <xsl:text>\includegraphics{</xsl:text>
        <xsl:value-of select="$filename" />
        <xsl:text>}&#xa;</xsl:text>
        <xsl:text>\caption{</xsl:text>
        <xsl:value-of select="@name" />
        <xsl:text>}&#xa;</xsl:text>
        <xsl:text>\label{fig:</xsl:text>
        <xsl:value-of select="@refid" />
        <xsl:text>}&#xa;</xsl:text>
        <xsl:text>\end{figure}&#xa;</xsl:text>

    </xsl:template>

    <xsl:template name="cell-link">
        <xsl:text>\href{</xsl:text>
        <xsl:value-of select="@href" />
        <xsl:text>}{</xsl:text>
        <xsl:value-of select="@name" />
        <xsl:text>}</xsl:text>
    </xsl:template>


</xsl:stylesheet>