<?xml version="1.0" encoding="utf-8"?>

<xsl:stylesheet version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:oo="http://www.omnigroup.com/namespace/OmniOutliner/v3"
    exclude-result-prefixes="oo"
>

    <xsl:output method="html"
              version="4.01"
              encoding="utf-8"
              doctype-public="-//W3C//DTD HTML 4.01 Transitional//EN"
              indent="yes"/>

<xsl:variable name="non-note-columns" select="oo:outline/oo:columns/oo:column[not(@is-note-column) or @is-note-column != 'yes']" />
<xsl:strip-space elements="*" />

<xsl:variable name="note-column-position">
    <xsl:for-each select="oo:outline/oo:columns">
      <xsl:if test="@is-note-column = 'yes'">
        <xsl:value-of select="position()"/>
      </xsl:if>
    </xsl:for-each>
</xsl:variable>

<xsl:variable name="outline-column-position">
    <xsl:for-each select="$non-note-columns">
      <xsl:if test="@is-outline-column = 'yes'">
        <xsl:value-of select="position()"/>
      </xsl:if>
    </xsl:for-each>
</xsl:variable>



    <xsl:template match="/">
        <html xsl:exclude-result-prefixes="oo">
          <head>
            <!-- TODO: Also add a parameter for whether to put the styled document title in the body? -->
            <title><xsl:value-of select="/oo:outline/oo:outline-title/oo:text/oo:p/oo:run/oo:lit"/></title>
          </head>
          <body>
            <ul>
                <xsl:apply-templates select="oo:outline/oo:root/oo:item" />
            </ul>
          </body>
        </html>
    </xsl:template>


    <xsl:template match="oo:item">
        <li>
            <xsl:apply-templates select="oo:values/*[number($outline-column-position)]"/>
            <xsl:apply-templates select="oo:note"/>

            <xsl:apply-templates select="oo:children"/>

        </li>
    </xsl:template>

    <xsl:template match="oo:note" >
<!--        <xsl:text>&#xa;</xsl:text> -->
        <ul style="list-style-type: none;">
            <li>
                <xsl:apply-templates />
            </li>
        </ul>
        <xsl:text>&#xa;&#xa;</xsl:text>
    </xsl:template>

    <xsl:template match="oo:text//oo:p | oo:note//oo:p" >
        <xsl:choose>
            <xsl:when test="position() != 1">
                <p>
                    <xsl:apply-templates />
                </p>
            </xsl:when>
            
            <xsl:otherwise>
                <xsl:apply-templates />
            </xsl:otherwise>
        </xsl:choose>

    </xsl:template>

    <!-- override the template found in column-formatters.xsl -->
    <xsl:template match="oo:run">
        <xsl:apply-templates />
    </xsl:template>

    <xsl:template match="oo:children">
        <ul>
            <xsl:apply-templates />
        </ul>
    </xsl:template>

    <xsl:template match="oo:cell">
        <a>
            <xsl:attribute name="href">
                <xsl:value-of select="@href"/>
                </xsl:attribute>
            <xsl:value-of select="@name"/>
            </a>
        <xsl:apply-templates />
        </xsl:template>
        
    <xsl:template match="oo:style" />

</xsl:stylesheet>